==> root_v6.24.06.source.tar.gz: root-6.24.06/graf3d/g3d/src/TMixture.cxx <==
// @(#)root/g3d:$Id$
// Author: Rene Brun   03/10/95

/*************************************************************************
 * Copyright (C) 1995-2000, Rene Brun and Fons Rademakers.               *
 * All rights reserved.                                                  *
 *                                                                       *
 * For the licensing terms see $ROOTSYS/LICENSE.                         *
 * For the list of contributors see $ROOTSYS/README/CREDITS.             *
 *************************************************************************/

#include "TMixture.h"

#include "TBuffer.h"
#include "TMath.h"

ClassImp(TMixture);

/** \class TMixture
\ingroup g3d
Manages a detector mixture. See class TGeometry.
*/

////////////////////////////////////////////////////////////////////////////////
/// Mixture default constructor.

TMixture::TMixture()
{
   fAmixt = 0;
   fZmixt = 0;
   fWmixt = 0;
   fNmixt = 0;
}

////////////////////////////////////////////////////////////////////////////////
/// Mixture normal constructor
///
/// Defines mixture OR COMPOUND as composed by
/// the basic nmixt materials defined later by DefineElement.
///
/// If nmixt > 0 then Wmixt contains the PROPORTION BY WEIGHTS
/// of each basic material in the mixture.
///
/// If nmixt < 0 then Wmixt contains the number of atoms
/// of a given kind into the molecule of the COMPOUND
/// In this case, Wmixt is changed to relative weights.
///
/// nb : the radiation length is computed according
/// the EGS manual slac-210 uc-32 June-78
/// formula  2-6-8 (37)

TMixture::TMixture(const char *name, const char *title, Int_t nmixt)
           :TMaterial(name,title,0,0,0)
{
   if (nmixt == 0) {
      fAmixt = 0;
      fZmixt = 0;
      fWmixt = 0;
      fNmixt = 0;
      Error("TMixture", "mixture number is 0");
      return;
   }
   Int_t nm = TMath::Abs(nmixt);
   fNmixt   = nmixt;
   fAmixt   = new Float_t[nm];
   fZmixt   = new Float_t[nm];
   fWmixt   = new Float_t[nm];
}

////////////////////////////////////////////////////////////////////////////////
/// Mixture default destructor.

TMixture::~TMixture()
{
   delete [] fAmixt;
   delete [] fZmixt;
   delete [] fWmixt;
   fAmixt = 0;
   fZmixt = 0;
   fWmixt = 0;
}

////////////////////////////////////////////////////////////////////////////////
/// Define one mixture element.

void TMixture::DefineElement(Int_t n, Float_t a, Float_t z, Float_t w)
{
   if (n < 0 || n >= TMath::Abs(fNmixt)) return;
   fAmixt[n] = a;
   fZmixt[n] = z;
   fWmixt[n] = w;
}

////////////////////////////////////////////////////////////////////////////////
/// Stream a class object.

void TMixture::Streamer(TBuffer &b)
{
   UInt_t R__s, R__c;
   if (b.IsReading()) {
      b.ReadVersion(&R__s, &R__c);
      TMaterial::Streamer(b);
      b >> fNmixt;
      Int_t nmixt = TMath::Abs(fNmixt);
      fAmixt   = new Float_t[nmixt];
      fZmixt   = new Float_t[nmixt];
      fWmixt   = new Float_t[nmixt];
      b.ReadArray(fAmixt);
      b.ReadArray(fZmixt);
      b.ReadArray(fWmixt);
      b.CheckByteCount(R__s, R__c, TMixture::IsA());
   } else {
      R__c = b.WriteVersion(TMixture::IsA(), kTRUE);
      TMaterial::Streamer(b);
      b << fNmixt;
      Int_t nmixt = TMath::Abs(fNmixt);
      b.WriteArray(fAmixt, nmixt);
      b.WriteArray(fZmixt, nmixt);
      b.WriteArray(fWmixt, nmixt);
      b.SetByteCount(R__c, kTRUE);
   }
}

==> root_v6.32.18.source.tar.gz: root-6.32.18/graf3d/g3d/src/TMixture.cxx <==
// @(#)root/g3d:$Id$
// Author: Rene Brun   03/10/95

/*************************************************************************
 * Copyright (C) 1995-2000, Rene Brun and Fons Rademakers.               *
 * All rights reserved.                                                  *
 *                                                                       *
 * For the licensing terms see $ROOTSYS/LICENSE.                         *
 * For the list of contributors see $ROOTSYS/README/CREDITS.             *
 *************************************************************************/

#include "TMixture.h"

#include "TBuffer.h"
#include "TMath.h"

ClassImp(TMixture);

/** \class TMixture
\ingroup g3d
Manages a detector mixture. See class TGeometry.
*/

////////////////////////////////////////////////////////////////////////////////
/// Mixture default constructor.

TMixture::TMixture()
{
   fAmixt = nullptr;
   fZmixt = nullptr;
   fWmixt = nullptr;
   fNmixt = 0;
}

////////////////////////////////////////////////////////////////////////////////
/// Mixture normal constructor
///
/// Defines mixture OR COMPOUND as composed by
/// the basic nmixt materials defined later by DefineElement.
///
/// If nmixt > 0 then Wmixt contains the PROPORTION BY WEIGHTS
/// of each basic material in the mixture.
///
/// If nmixt < 0 then Wmixt contains the number of atoms
/// of a given kind into the molecule of the COMPOUND
/// In this case, Wmixt is changed to relative weights.
///
/// nb : the radiation length is computed according
/// the EGS manual slac-210 uc-32 June-78
/// formula  2-6-8 (37)

TMixture::TMixture(const char *name, const char *title, Int_t nmixt)
           :TMaterial(name,title,0,0,0)
{
   if (nmixt == 0) {
      fAmixt = nullptr;
      fZmixt = nullptr;
      fWmixt = nullptr;
      fNmixt = 0;
      Error("TMixture", "mixture number is 0");
      return;
   }
   Int_t nm = TMath::Abs(nmixt);
   fNmixt   = nmixt;
   fAmixt   = new Float_t[nm];
   fZmixt   = new Float_t[nm];
   fWmixt   = new Float_t[nm];
}

////////////////////////////////////////////////////////////////////////////////
/// Mixture default destructor.

TMixture::~TMixture()
{
   delete [] fAmixt;
   delete [] fZmixt;
   delete [] fWmixt;
   fAmixt = nullptr;
   fZmixt = nullptr;
   fWmixt = nullptr;
}

////////////////////////////////////////////////////////////////////////////////
/// Define one mixture element.

void TMixture::DefineElement(Int_t n, Float_t a, Float_t z, Float_t w)
{
   if (n < 0 || n >= TMath::Abs(fNmixt)) return;
   fAmixt[n] = a;
   fZmixt[n] = z;
   fWmixt[n] = w;
}

////////////////////////////////////////////////////////////////////////////////
/// Stream a class object.

void TMixture::Streamer(TBuffer &b)
{
   UInt_t R__s, R__c;
   if (b.IsReading()) {
      b.ReadVersion(&R__s, &R__c);
      TMaterial::Streamer(b);
      b >> fNmixt;
      Int_t nmixt = TMath::Abs(fNmixt);
      fAmixt   = new Float_t[nmixt];
      fZmixt   = new Float_t[nmixt];
      fWmixt   = new Float_t[nmixt];
      b.ReadArray(fAmixt);
      b.ReadArray(fZmixt);
      b.ReadArray(fWmixt);
      b.CheckByteCount(R__s, R__c, TMixture::IsA());
   } else {
      R__c = b.WriteVersion(TMixture::IsA(), kTRUE);
      TMaterial::Streamer(b);
      b << fNmixt;
      Int_t nmixt = TMath::Abs(fNmixt);
      b.WriteArray(fAmixt, nmixt);
      b.WriteArray(fZmixt, nmixt);
      b.WriteArray(fWmixt, nmixt);
      b.SetByteCount(R__c, kTRUE);
   }
}
